# Quick Start
You can use `Rehearser` to build reliable unit tests quickly

Please check https://github.com/kevinchwong/rehearser-examples

----

## Installation

```bash
pip install rehearser
```



